Documentation
¶
Overview ¶
internal/app/app.go
internal/app/editor_api.go
Index ¶
- type App
- func (a *App) CloseBuffer() error
- func (a *App) ForceCloseBuffer()
- func (a *App) GetModeHandler() *modehandler.ModeHandler
- func (a *App) GetTheme() *theme.Theme
- func (a *App) GetThemeManager() *theme.Manager
- func (a *App) ListThemes() []string
- func (a *App) NextBuffer()
- func (a *App) OpenFile(filePath string)
- func (a *App) PrevBuffer()
- func (a *App) Run() error
- func (a *App) SetStatusMessage(format string, args ...interface{})
- func (a *App) SetTheme(name string) error
- type HighlightingManager
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type App ¶
type App struct {
// contains filtered or unexported fields
}
App encapsulates the core components and main loop of the editor.
func (*App) CloseBuffer ¶ added in v0.1.3
CloseBuffer closes the active buffer
func (*App) ForceCloseBuffer ¶ added in v0.1.3
func (a *App) ForceCloseBuffer()
ForceCloseBuffer closes the active buffer without checking for modifications
func (*App) GetModeHandler ¶
func (a *App) GetModeHandler() *modehandler.ModeHandler
GetModeHandler allows the API adapter to access the mode handler.
func (*App) GetThemeManager ¶
GetThemeManager returns the app's theme manager
func (*App) ListThemes ¶ added in v0.1.1
ListThemes returns available theme names.
func (*App) NextBuffer ¶ added in v0.1.3
func (a *App) NextBuffer()
NextBuffer switches to the next buffer
func (*App) OpenFile ¶ added in v0.1.3
OpenFile opens a file in a new buffer or switches to it if already open
func (*App) PrevBuffer ¶ added in v0.1.3
func (a *App) PrevBuffer()
PrevBuffer switches to the previous buffer
func (*App) SetStatusMessage ¶
SetStatusMessage sets a temporary message.
type HighlightingManager ¶
type HighlightingManager struct {
// contains filtered or unexported fields
}
HighlightingManager handles debounced asynchronous syntax highlighting.
func NewHighlightingManager ¶
func NewHighlightingManager(editor *core.Editor, highlighter *highlighter.Highlighter, redrawFunc func()) *HighlightingManager
NewHighlightingManager creates a manager.
func (*HighlightingManager) AccumulateEdit ¶
func (hm *HighlightingManager) AccumulateEdit(edit types.EditInfo)
AccumulateEdit adds an edit to the pending list and triggers/resets the timer.
func (*HighlightingManager) Shutdown ¶
func (hm *HighlightingManager) Shutdown()
Shutdown cancels any pending/running tasks.
func (*HighlightingManager) TriggerUpdate ¶
func (hm *HighlightingManager) TriggerUpdate()
TriggerUpdate is kept for backward compatibility but now does nothing as AccumulateEdit is the new entry point